04. Texture
***********

.. figure:: images/04_textures.png
	:scale: 50 %
	:alt: 04_textures
	:align: center
	:figclass: align-center

	Textures

.. literalinclude:: ../../examples/GLWindow/04_textures.py
	:linenos:
